# frozen_string_literal: true

ENV['THOR_SILENCE_DEPRECATION'] = 'true'

require 'faraday'
require 'faraday_middleware'
require 'learn_web'
require 'logger'
require 'oauth2'
require 'sinatra/base'
require 'thin'

# TTY Libraries
require 'tty-link'
require 'tty-prompt'
require 'tty-config'
require 'zeitwerk'

loader = Zeitwerk::Loader.for_gem
loader.log! if ENV['DEBUG']
loader.inflector.inflect 'fis' => 'FIS'
loader.inflector.inflect 'cli' => 'CLI'
loader.inflector.inflect 'ui' => 'UI'
loader.setup

# Entry point for the FIS CLI
module FIS
  class Error < StandardError; end

  class << self
    attr_writer :ui

    def ui
      @ui ||= UI.new(TTY::Prompt.new)
    end

    def config
      @config ||= Configuration.new
    end

    def client
      @client ||= begin
        token = config.fetch(:identity, :portal, :token)

        if token.nil? || token.empty?
          FIS.ui.newline
          FIS.ui.error("You're not logged in. Please run `fis auth login` to continue.")
          exit
        end

        Client::Base.new(token: token)
      end
    end
  end
end
