# frozen_string_literal: true

# PKCE modifies the standard authorization code grant.
# https://doorkeeper.gitbook.io/guides/ruby-on-rails/pkce-flow

module FIS
  module Auth
    # OAuth2 + PKCE helper class for authenticating against portal.flatironschool.com
    class Client
      CODE_CHALLENGE_METHOD = 'S256'

      def initialize
        @client = OAuth2::Client.new(
          Auth::CLIENT_ID,
          nil,
          site: Auth::PROVIDER_URL,
          redirect_uri: Auth::REDIRECT_URI
        )
      end

      def authorize_url
        @client.auth_code.authorize_url(
          code_challenge: code_challenge,
          code_challenge_method: CODE_CHALLENGE_METHOD
        )
      end

      def get_token(code:)
        @client.auth_code.get_token(code, code_verifier: code_verifier)
      end

      private

      def code_challenge
        padded_result = Base64.urlsafe_encode64(Digest::SHA256.digest(code_verifier))
        padded_result.split('=')[0] # Remove trailing '='
      end

      def code_verifier
        @code_verifier ||= SecureRandom.hex(128)
      end
    end
  end
end
