# frozen_string_literal: true

require 'sinatra/base'

module FIS
  module Auth
    # Local Sinatra server to respond to OAuth2 code requests.
    class Server < Sinatra::Base
      enable :raise_errors, :quiet
      disable :sessions, :logging, :show_exceptions

      set :bind, '127.0.0.1'
      set :port, 4444

      def initialize
        @auth = FIS::Auth::Client.new
        super(nil)
      end

      get '/' do
        redirect @auth.authorize_url
      end

      get '/callback' do
        auth = @auth.get_token(code: params[:code])

        FIS.config.set(:identity, :portal, :token) { auth.token }

        'Success! You may close this window and return to the CLI.'
      rescue # rubocop:disable Style/RescueStandardError
        'Authentication failure. Please try again from the CLI'
      end
    end
  end
end
