# frozen_string_literal: true

module FIS
  module CLI
    module Commands
      # `auth login` - Requests and adds the user's authentication credentials
      class Login < Command
        def initialize(options)
          @options = options
          @auth_local_server = FIS::Auth::Runner.new
        end

        def execute
          # TODO: Allow for token to be set with a flag

          FIS.ui.newline

          return FIS.ui.error("You're already logged in. Please run `fis auth logout` to continue.") if logged_in?
          return FIS.ui.warn('OAuth not available. Please set your token using the `--token` flag.') if remote_ide?

          @auth_local_server.start

          FIS.ui.info('Logging into your Flatiron School account...')
          open_browser!

          sleep 1 until token_accessible? # TODO: Timeout?

          FIS.ui.newline

          FIS.ui.ok("You've successfully logged in.")
        ensure
          @auth_local_server.stop
        end

        private

        def logged_in?
          FIS.config.fetch(:identity, :portal, :token)
        end

        def open_browser!
          system('open', FIS::Auth::LOCAL_URI)
        end

        def remote_ide?
          false # TODO: Check if in an environment without a browser
        end

        def token_accessible?
          FIS.config.reread
          token = FIS.config.fetch(:identity, :portal, :token)
          !token.nil? && !token.empty?
        end
      end
    end
  end
end
