# frozen_string_literal: true

module FIS
  module Client
    class Base
      BASE_URL = ENV.fetch('FIS_CLIENT_BASE_URL', 'https://portal.flatironschool.com')
      API_ROOT = '/api/v1'

      CLIENT_ERROR_STATUSES = [400, 401, 403, 407, 422].freeze
      SERVER_ERROR_STATUSES = (500..511).to_a.freeze

      ERROR_STATUSES = (CLIENT_ERROR_STATUSES + SERVER_ERROR_STATUSES).freeze

      attr_reader :client

      def initialize(token:)
        url = [BASE_URL, API_ROOT].join

        @client = Faraday.new(url: url) do |conn|
          conn.authorization :Bearer, token

          conn.response :json, 
                        content_type: 'application/json',
                        parser_options: {
                          object_class: OpenStruct 
                        }
          
          conn.request :retry,
                       max: 3,
                       interval: 2,
                       interval_randomness: 0.5,
                       backoff_factor: 2,
                       methods: Faraday::Request::Retry::IDEMPOTENT_METHODS + [:post],
                       retry_statuses: ERROR_STATUSES,
                       exceptions: Faraday::Request::Retry::DEFAULT_EXCEPTIONS

          conn.adapter Faraday.default_adapter
        end
      end

      def valid_token?
        !!user.data
      end

      def user
        @user ||= User.new(base: self)
      end
    end
  end
end
