# frozen_string_literal: true

require 'forwardable'

module FIS
  # Class responsible for displaying different level information
  class UI
    extend Forwardable

    def_delegators :@prompt, :ok, :ask, :mask, :suggest

    def initialize(prompt)
      @prompt = prompt
      @debug = ENV['DEBUG']
      @shell = Thor::Shell::Basic.new
    end

    def newline(num = 1)
      @prompt.say("\n" * num)
    end

    def info(message)
      @prompt.say(message)
    end

    def warn(message)
      @prompt.warn(message)
    end

    def error(message)
      @prompt.error(message)
    end

    def debug(error, newline = nil)
      return unless @debug

      message = ["#{error.class}: #{error.message}", *error.backtrace]
      @prompt.say(newline ? message.join("\n") : message)
    end

    def debug!
      @debug = true
    end

    def print_table(table, options = {})
      @shell.print_table(table, options)
    end

    def print_link(title, url)
      @prompt.say(format_link(title, url))
    end

    def format_link(title, url)
      TTY::Link.link_to(title, url)
    end
  end
end
